package Moonshine::Bootstrap::v3::NavbarButton;

use Moonshine::Magic;

extends (
    'Moonshine::Bootstrap::Component',
    'Moonshine::Bootstrap::v3::Button',
); 

with 'Moonshine::Bootstrap::Component::NavbarButton';

1;


