package Moonshine::Bootstrap::v3::EmbedRes;

use Moonshine::Magic;

with (
    'Moonshine::Bootstrap::Component::EmbedRes', 
);

extends (
    'Moonshine::Bootstrap::v3::EmbedResponsive',  
    'Moonshine::Bootstrap::v3::EmbedResponsiveIframe',  
);

1;


