package Moonshine::Bootstrap::v3::ListGroup;

use Moonshine::Magic;

extends (
    'Moonshine::Bootstrap::Component',
    'Moonshine::Bootstrap::v3::ListGroupItem',
); 

with 'Moonshine::Bootstrap::Component::ListGroup';

1;


