package Moonshine::Bootstrap::v3::NavbarForm;

use Moonshine::Magic;

extends (
    'Moonshine::Bootstrap::Component',
    'Moonshine::Bootstrap::v3::SubmitButton',
    'Moonshine::Bootstrap::v3::FormGroup',
); 

with 'Moonshine::Bootstrap::Component::NavbarForm';

1;


