package Moonshine::Bootstrap::v3::ListedGroup;

use Moonshine::Magic;

extends (
    'Moonshine::Bootstrap::Component',
    'Moonshine::Bootstrap::v3::ListedGroupItem',
); 

with 'Moonshine::Bootstrap::Component::ListedGroup';

1;


