package Moonshine::Bootstrap::v3::EmbedResponsiveIframe;

use Moonshine::Magic;

extends (
    'Moonshine::Bootstrap::Component'
);

with 'Moonshine::Bootstrap::Component::EmbedResponsiveIframe';

1;


