package Moonshine::Bootstrap::v3::InputGroup;

use Moonshine::Magic;

extends (
    'Moonshine::Bootstrap::Component',
	'Moonshine::Bootstrap::v3::InputGroupAddon',
); 

with 'Moonshine::Bootstrap::Component::InputGroup';

1;


