package Moonshine::Bootstrap::v3::ListedGroupItemHeading;

use Moonshine::Magic;

extends (
    'Moonshine::Bootstrap::Component'
); 

with 'Moonshine::Bootstrap::Component::ListedGroupItemHeading';

1;


