package Moonshine::Bootstrap::v3::Progress;

use Moonshine::Magic;

extends (
    'Moonshine::Bootstrap::Component',
    'Moonshine::Bootstrap::v3::ProgressBar'
); 

with 'Moonshine::Bootstrap::Component::Progress';

1;


